# CGSTATS [![Build Status][travis-img]][travis-url]

Models and CRUD to cgstats.

## configuration

cgstats has a parameter `--database` that needs to hold a connection string to the database:

```bash
$ cgstats --database mysql+pymysql://user:pass@127.0.0.1:3306/cgstats
```

[travis-img]: https://travis-ci.org/Clinical-Genomics/cgstats.svg?branch=master
[travis-url]: https://travis-ci.org/Clinical-Genomics/cgstats
